quantizationtools.WeightedSearchTree
====================================

.. abjad-lineage:: abjad.tools.quantizationtools.WeightedSearchTree.WeightedSearchTree.WeightedSearchTree

.. autoclass:: abjad.tools.quantizationtools.WeightedSearchTree.WeightedSearchTree.WeightedSearchTree

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.quantizationtools.WeightedSearchTree.WeightedSearchTree.WeightedSearchTree.all_compositions
      ~abjad.tools.quantizationtools.WeightedSearchTree.WeightedSearchTree.WeightedSearchTree.default_definition
      ~abjad.tools.quantizationtools.WeightedSearchTree.WeightedSearchTree.WeightedSearchTree.definition
      ~abjad.tools.quantizationtools.WeightedSearchTree.WeightedSearchTree.WeightedSearchTree.__call__
      ~abjad.tools.quantizationtools.WeightedSearchTree.WeightedSearchTree.WeightedSearchTree.__eq__
      ~abjad.tools.quantizationtools.WeightedSearchTree.WeightedSearchTree.WeightedSearchTree.__getstate__
      ~abjad.tools.quantizationtools.WeightedSearchTree.WeightedSearchTree.WeightedSearchTree.__ne__
      ~abjad.tools.quantizationtools.WeightedSearchTree.WeightedSearchTree.WeightedSearchTree.__repr__
      ~abjad.tools.quantizationtools.WeightedSearchTree.WeightedSearchTree.WeightedSearchTree.__setstate__

Bases
-----

- :py:class:`quantizationtools.SearchTree <abjad.tools.quantizationtools.SearchTree.SearchTree.SearchTree>`

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.quantizationtools.WeightedSearchTree.WeightedSearchTree.WeightedSearchTree.all_compositions
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.WeightedSearchTree.WeightedSearchTree.WeightedSearchTree.default_definition
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.WeightedSearchTree.WeightedSearchTree.WeightedSearchTree.definition
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.quantizationtools.WeightedSearchTree.WeightedSearchTree.WeightedSearchTree.__call__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.WeightedSearchTree.WeightedSearchTree.WeightedSearchTree.__eq__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.WeightedSearchTree.WeightedSearchTree.WeightedSearchTree.__getstate__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.WeightedSearchTree.WeightedSearchTree.WeightedSearchTree.__ne__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.WeightedSearchTree.WeightedSearchTree.WeightedSearchTree.__repr__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.WeightedSearchTree.WeightedSearchTree.WeightedSearchTree.__setstate__
   :noindex:
